/**
 * Program: ClientUtils.java
 * Comments: This class collects several static utility methods that client 
 * programs will typically use.  Note this isn't a WebFlow module.
 */

package WebFlow;

import java.io.*;
import java.net.*;
import java.util.*;
import org.omg.CORBA.*;
import javax.swing.*;

public class ClientUtils {
    
    /**
     * Return the IOR from the specified file.
     */
    public static String getIORFromURL(String urlString){
	String masterServerIOR="";
	String thisLine=null;
	try {
	    URL u = new URL(urlString);
	    try {
		DataInputStream theHTML = new DataInputStream(u.openStream());
		try {
		    while ((thisLine = theHTML.readLine()) != null) {
			masterServerIOR += thisLine;
		    } 
		} 
		catch (Exception e) {
		    System.out.println("getIORfromURL:"+e);
		}
	    } 
	    catch (Exception e) {
		System.out.println("getIORfromURL:"+e);
        }
	    
	} 
	catch (MalformedURLException e) {
	    System.out.println("getIORfromURL:"+urlString 
			       + " is not a parseable URL");
	    System.out.println("getIORfromURL:"+e);
	}
	return masterServerIOR;
    }
    
    /**
     * Initialize the orb.  Set the properties to override the ORB 
     * in the sun release.  
     */
    public static ORB initializeORB(String IorURL,ORB orb) {
	Properties props = System.getProperties();
	props.put("org.omg.CORBA.ORBClass", "com.ooc.CORBA.ORB");
	props.put("org.omg.CORBA.ORBSingletonClass", 
		  "com.ooc.CORBA.ORBSingleton");
	System.setProperties(props);
	String[] args = new String[1];
	args[0]=IorURL;
	orb = ORB.init(args, props);
	return orb;
    }

    /**
     * Initialize the orb for an applet.  Because of security restrictions,
     * system properties cannot be modified by an applet.
     */
    public static ORB initAppletORB(JApplet applet) {
	ORB orb = ORB.init(applet,new java.util.Properties());
	System.out.println("Orb is initialized");
	return orb;
    }

    /**
     * Create the webflow master server.
     */
    public static WebFlowContext getMasterServer(String masterIOR,ORB orb){
	WebFlowContext ws = null;
	System.out.println("masterIOR is "+masterIOR);
	try {
	    org.omg.CORBA.Object o = orb.string_to_object(masterIOR);
	    ws = WebFlowContextHelper.narrow(o);
	}
	catch (Exception e) {
	    System.out.println("getMasterServer: "+e);
	    e.printStackTrace();
	}
	return ws;
    }

    /**
     * Create a module object.  The user will have to narrow this.  
     */

    public static org.omg.CORBA.Object 
	makeModule(WebFlowContext master,String moduleName) {
	org.omg.CORBA.Object obj=null;
	if(master==null) {
	    System.err.println("Server context is null");
	}
	else {
	    obj=master.addNewModule(moduleName);
	}
	return obj;
    }
}
