/**
 * Program Name: createPBS.java
 * Comments: This class is a child of the createScript abstract parent.  
 * Creates a PBS script.
 * 
 * Note that the ContextManager object cm and the string scriptString are
 * protected data inherited from the parent.
 *
 * I am assuming the following naming convention for the context data:
 *
 *   shell: the unix shell to use.
 *   queue: the particular queue (default, challenge, and so on).
 *   Name: the name to give the job.
 *   NNodes: the number of nodes to request.
 *   walltime: the maximum time per node.
 *   Account#: the user's account number.
 * 
 * Note that all of these variables are not required.
 */

package extensions.generic;
import WebFlow.*;
import WebFlow.ContextManager.*;
import java.io.*;

public class createPBS {
    String pbsHead="#PBS";

    /**
     * This method concatentates the PBS-specific header directives
     * to the string scriptString, inherited from the parent.
     * It probably wouldn't hurt at some point to associate the 
     * param names with their flags (shell and -S, for example).
     */
    public void createHeader() {
	scriptString+="#! /bin/csh";
	if(!cm.getCurrentProblemProperty("shell")==null) {
	    scriptString+=pbsHead+" -S "
		+cm.getCurrentProblemProperty("shell")+"\n";
	}
	if(!cm.getCurrentProblemProperty("queue")==null) {
	    scriptString+=pbsHead+" -q "
		+cm.getCurrentProblemProperty("queue")+"\n";
	}
	if(!cm.getCurrentProblemProperty("Name")==null) {
	    scriptString+=pbsHead+" -N "
		+cm.getCurrentProblemProperty("Name")+"\n";
	    scriptString+=pbsHead+" -j oe\n";
	    scriptString+=pbsHead
		+" -o "+cm.getCurrentProblemProperty("Name")+".oe";
	}
	if(!cm.getCurrentProblemProperty("NNodes")==null) {
	    scriptString+=pbsHead+" -l "
		+"nodes="+cm.getCurrentProblemProperty("NNodes")+"\n";
	}
	if(!cm.getCurrentProblemProperty("walltime")==null) {
	    scriptString+=pbsHead+" -l "
		+"walltime="
		+cm.getCurrentProblemProperty("walltime")+"\n";
	}
	if(!cm.getCurrentProblemProperty("Account#")==null) {
	    scriptString+=pbsHead+" -A "
		+cm.getCurrentProblemProperty("Account#")+"\n";
	}
	
	
    }
    
}


